.. _nlp_en_transforms_tokens:

============
:mod:`lexnlp.nlp.en.transforms.tokens`: Transforming text into token-oriented features
============

The :mod:`lexnlp.nlp.en.transforms.tokens` module contains methods
that transform text into token distributions or related feature vectors.

.. attention::
    The sections below are a work in progress.  Thank you for your patience
    while we continue to expand and improve our documentation coverage.

    If you have any questions in the meantime, please feel free to log issues on
    GitHub at the URL below or contact us at the email below:

    - GitHub issues: https://github.com/LexPredict/lexpredict-lexnlp
    - Email: support@contraxsuite.com

.. automodapi:: lexnlp.nlp.en.transforms.tokens
    :include-all-objects:
    :members:

